@@ -5,12 +5,13 @@ from datetime import datetime
 
 
 class Compare:
-    def __init__ (self, tested, expected, key=None):
-        self.data = PrepareForComparison(tested, expected, key)
+    def __init__ (self, tested, expected, key=None, verbose=False):
+        self.data = PrepareForComparison(tested, expected, key, verbose=verbose)
         self.tested = self.data.tested
         self.expected = self.data.expected
-        self.string_comparisons = StringComparisons(prepared_data=self.data)
-        self.numeric_comparisons = NumericComparisons(prepared_data=self.data)
+        self.string_comparisons = StringComparisons(prepared_data=self.data, verbose=self.data.verbose)
+        self.numeric_comparisons = NumericComparisons(prepared_data=self.data, verbose=self.data.verbose)
+ 
         
     def report (self):
         report = []
